@@ -23,22 +23,53 @@ coloring outside the lines; consider yourself warned.
 Grabs the connection status page from the modem, returns the given HTML
 as an array of lines.
 =cut
+
+# The URL's have changed over time
+my @urls = (
+	# This one exists in SW version 3.1.0.1pre3 and possibly earlier
+	'admin/cable-status.asp',
+
+	# This one existed in older stuff, back in 2011 and for some time
+	# after.
+	'status_connection.asp',
+);
+my $url; # Chosen one for this modem
+
 sub fetch_page_rows
 {
 	my $self = shift;
 
 	use LWP::UserAgent;
 	my $ua = LWP::UserAgent->new;
-	my $url = "http://$self->{modem_addr}/status_connection.asp";
-	my $req = HTTP::Request->new(GET => $url);
-	my $res = $ua->request($req);
 
-	croak "Failed HTTP GET on $url: @{[$res->status_line]}"
-			unless($res->is_success);
+	# Use the URL we already found, if we found one; otherwise try 'em
+	# all.
+	my @uopts = $url ? ($url) : (@urls);
 
+	# Try each of our candidates until one succeeds or we run out
+	my @uerrs;
+	my $res;
+	for my $u (@uopts)
+	{
+		$url = "http://$self->{modem_addr}/$u";
+		my $req = HTTP::Request->new(GET => $url);
+		$res = $ua->request($req);
+
+		# Got it? Go ahead.
+		last if $res->is_success;
+
+		# Otherwise rack up an error, and loop back around.
+		push @uerrs, "Failed HTTP GET on $url: @{[$res->status_line]}";
+	}
+
+	# If things failed, dump out all the errors
+	croak join "\n", @uerrs unless $res->is_success;
+
+	# Make sure we got actual data
 	my $html = $res->content;
 	croak "Got no data from $url" unless($html);
 
+	# Put it together and hand it back.
 	my @html = split /\n/, $html;
 	chomp @html;
 
