@@ -41,3 +41,9 @@ sub load_test_data
 
 
 1;
+__END__
+
+=head1 SEE ALSO
+
+You should probably be looking at L<Device::CableModem::Zoom5341>
+instead.
